"""
Utils to run tests
"""
from django.db import models
from opaque_keys.edx.django.models import CourseKeyField

try:
    from django_fake_model import models as fake

    class CourseOverview(fake.FakeModel):
        """Fake Model enrollments."""
        course_id = CourseKeyField(max_length=255)

except ImportError:
    CourseOverview = object

try:
    from django_fake_model import models as fake

    class CourseEnrollment(fake.FakeModel):
        """Fake Model enrollments."""
        username = models.CharField(max_length=255, null=True)
        course_id = models.CharField(max_length=255, null=True)

except ImportError:
    CourseEnrollment = object



"""
Backend CourseOverview file, here are all the methods from
openedx.core.djangoapps.content.course_overviews.
"""


def get_course_overview():
    """Backend to get course overview."""
    try:
        from openedx.core.djangoapps.content.course_overviews.models import CourseOverview
    except ImportError:
        from eox_tagging.test.test_utils import CourseOverview
    return CourseOverview
